@@ -8,22 +8,25 @@ with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 """
 
-__version__ = "0.0.0"
+__version__ = "0.0.11"
 AUTHOR = "Vanessa Sochat"
 AUTHOR_EMAIL = "vsochat@stanford.edu"
 NAME = "rseng"
-PACKAGE_URL = "http://www.github.com/rseng/rseng"
-KEYWORDS = "rseng,software,research software,database,taxonomy"
-DESCRIPTION = "tools for assessment and categorization of research software"
+PACKAGE_URL = "https://github.com/rseng/rseng"
+KEYWORDS = "rse,software,research software,criteria,taxonomy"
+DESCRIPTION = "criteria and taxonomy for research software engineering"
 LICENSE = "LICENSE"
 
 ################################################################################
 # Global requirements
 
 
-INSTALL_REQUIRES = ()
-DATABASE_REQUIRES = (("sqlalchemy", {"min_version": None}),)
+INSTALL_REQUIRES = (
+    ("requests", {"min_version": "2.23.0"}),
+    ("pyaml", {"min_version": "20.3.1"}),
+    ("Jinja2", {"min_version": None}),
+)
 TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)
 
 
-ALL_REQUIRES = INSTALL_REQUIRES + DATABASE_REQUIRES
+ALL_REQUIRES = INSTALL_REQUIRES
